==> de-2.11.2.zip: de/date.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%Y-%m-%d %H:%M'] = '%d.%m.%Y %H:%M';
$GLOBALS['__l10n']['_Jan'] = 'Jan.';
$GLOBALS['__l10n']['_Feb'] = 'Feb.';
$GLOBALS['__l10n']['_Mar'] = 'Mär.';
$GLOBALS['__l10n']['_Apr'] = 'Apr.';
$GLOBALS['__l10n']['_May'] = 'Mai';
$GLOBALS['__l10n']['_Jun'] = 'Jun.';
$GLOBALS['__l10n']['_Jul'] = 'Jul.';
$GLOBALS['__l10n']['_Aug'] = 'Aug.';
$GLOBALS['__l10n']['_Sep'] = 'Sep.';
$GLOBALS['__l10n']['_Oct'] = 'Okt.';
$GLOBALS['__l10n']['_Nov'] = 'Nov.';
$GLOBALS['__l10n']['_Dec'] = 'Dez.';
$GLOBALS['__l10n']['January'] = 'Januar';
$GLOBALS['__l10n']['February'] = 'Februar';
$GLOBALS['__l10n']['March'] = 'März';
$GLOBALS['__l10n']['April'] = 'April';
$GLOBALS['__l10n']['May'] = 'Mai';
$GLOBALS['__l10n']['June'] = 'Juni';
$GLOBALS['__l10n']['July'] = 'Juli';
$GLOBALS['__l10n']['August'] = 'August';
$GLOBALS['__l10n']['September'] = 'September';
$GLOBALS['__l10n']['October'] = 'Oktober';
$GLOBALS['__l10n']['November'] = 'November';
$GLOBALS['__l10n']['December'] = 'Dezember';
$GLOBALS['__l10n']['_Mon'] = 'Mo.';
$GLOBALS['__l10n']['_Tue'] = 'Di.';
$GLOBALS['__l10n']['_Wed'] = 'Mi.';
$GLOBALS['__l10n']['_Thu'] = 'Do.';
$GLOBALS['__l10n']['_Fri'] = 'Fr.';
$GLOBALS['__l10n']['_Sat'] = 'Sa.';
$GLOBALS['__l10n']['_Sun'] = 'So.';
$GLOBALS['__l10n']['Monday'] = 'Montag';
$GLOBALS['__l10n']['Tuesday'] = 'Dienstag';
$GLOBALS['__l10n']['Wednesday'] = 'Mittwoch';
$GLOBALS['__l10n']['Thursday'] = 'Donnerstag';
$GLOBALS['__l10n']['Friday'] = 'Freitag';
$GLOBALS['__l10n']['Saturday'] = 'Samstag';
$GLOBALS['__l10n']['Sunday'] = 'Sonntag';

==> de-2.13.zip: de/date.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%Y-%m-%d %H:%M'] = '%d.%m.%Y %H:%M';
$GLOBALS['__l10n']['_Jan'] = 'Jan';
$GLOBALS['__l10n']['_Feb'] = 'Feb';
$GLOBALS['__l10n']['_Mar'] = 'Mär';
$GLOBALS['__l10n']['_Apr'] = 'Apr';
$GLOBALS['__l10n']['_May'] = 'Mai';
$GLOBALS['__l10n']['_Jun'] = 'Jun';
$GLOBALS['__l10n']['_Jul'] = 'Jul';
$GLOBALS['__l10n']['_Aug'] = 'Aug';
$GLOBALS['__l10n']['_Sep'] = 'Sep';
$GLOBALS['__l10n']['_Oct'] = 'Okt';
$GLOBALS['__l10n']['_Nov'] = 'Nov';
$GLOBALS['__l10n']['_Dec'] = 'Dez';
$GLOBALS['__l10n']['January'] = 'Januar';
$GLOBALS['__l10n']['February'] = 'Februar';
$GLOBALS['__l10n']['March'] = 'März';
$GLOBALS['__l10n']['April'] = 'April';
$GLOBALS['__l10n']['May'] = 'Mai';
$GLOBALS['__l10n']['June'] = 'Juni';
$GLOBALS['__l10n']['July'] = 'Juli';
$GLOBALS['__l10n']['August'] = 'August';
$GLOBALS['__l10n']['September'] = 'September';
$GLOBALS['__l10n']['October'] = 'Oktober';
$GLOBALS['__l10n']['November'] = 'November';
$GLOBALS['__l10n']['December'] = 'Dezember';
$GLOBALS['__l10n']['_Mon'] = 'Mo';
$GLOBALS['__l10n']['_Tue'] = 'Di';
$GLOBALS['__l10n']['_Wed'] = 'Mi';
$GLOBALS['__l10n']['_Thu'] = 'Do';
$GLOBALS['__l10n']['_Fri'] = 'Fr';
$GLOBALS['__l10n']['_Sat'] = 'Sa';
$GLOBALS['__l10n']['_Sun'] = 'So';
$GLOBALS['__l10n']['Monday'] = 'Montag';
$GLOBALS['__l10n']['Tuesday'] = 'Dienstag';
$GLOBALS['__l10n']['Wednesday'] = 'Mittwoch';
$GLOBALS['__l10n']['Thursday'] = 'Donnerstag';
$GLOBALS['__l10n']['Friday'] = 'Freitag';
$GLOBALS['__l10n']['Saturday'] = 'Samstag';
$GLOBALS['__l10n']['Sunday'] = 'Sonntag';
